import { Feature, FeatureWithRouterFactory } from '@common-stack/client-react';
import { interfaces } from 'inversify';
import LayoutModule from '@workbench-stack/layout';
import ModalModule from '@workbench-stack/modal';
import { ThemeModule } from '@workbench-stack/components';
import SettingsModule from '@workbench-stack/settings';
import OutputModule from '@workbench-stack/output-browser';
import { resolvers, editorSchema, editorInputSchema, editorLayoutSchema, contextSchema, defaults, fragmentMatcher } from './graphql';
import { workbenchModule } from './containers';
import { IEditorService, ClientTypes, IModelService, IClientService, IModeService, IContextKeyService, IResourceContextKey } from '@workbench-stack/core';

const workbenchServiceGen = (container: interfaces.Container): IClientService => {
  return {
    editorService: container.get<IEditorService>(ClientTypes.IEditorService),
    modelService: container.get<IModelService>(ClientTypes.IModelService),
    modeService: container.get<IModeService>(ClientTypes.IModeService),
    contextKeyService: container.get<IContextKeyService>(ClientTypes.IContextKeyService),
    resourceContextKey: container.get<IResourceContextKey>(ClientTypes.IResourceContextKey),
  };
};


export default new Feature(
  FeatureWithRouterFactory,
  LayoutModule, ThemeModule,
  ModalModule, SettingsModule,
  OutputModule,
  new Feature({
    clientStateParams: [{ resolvers, typeDefs: [editorSchema, editorInputSchema, editorLayoutSchema, contextSchema], defaults, fragmentMatcher: <any>fragmentMatcher }],
    createContainerFunc: workbenchModule,
    createServiceFunc: workbenchServiceGen,
  }),
);
